@@ -16,7 +16,7 @@ fbDeleteAdAccountUsers <-  function(user_ids     = NULL,
     }
   }
   
-  if ( class(access_token) == "fb_access_token" ) {
+  if ( inherits(access_token, "fb_access_token") ) {
     
     access_token <- access_token$access_token
     
